@@ -4,7 +4,7 @@ use base 'Exporter';
 use Carp;
 use vars qw(@EXPORT_OK @ATTRIBUTE);
 @EXPORT_OK = qw(ACTIVE SUSPEND QUEUED RUNNING R W E T);
-@ATTRIBUTE = qw(cb cbtime clump desc debug prio reentrant repeat max_cb_tm);
+@ATTRIBUTE = qw(cb cbtime desc debug prio reentrant repeat max_cb_tm);
 
 sub register {
     no strict 'refs';
@@ -94,6 +94,11 @@ sub configure {
     }
 }
 
+sub clump {
+    require Carp;
+    Carp::cluck "clump is deprecated";
+}
+
 package Event::Watcher::Tied;
 use vars qw(@ISA @ATTRIBUTE);
 @ISA = 'Event::Watcher';
